==> portal-transparencia-1.98.0.zip: BOOT-INF/classes/db/sql/contab/receitasPorFonteRecurso.sql <==
SELECT TB2.*
FROM
(SELECT CAST(TB1.FONTERECURSO AS NUMERIC(15))  AS RECEITA,
       TB1.DESCRICAO,
			 SUM(TB1.VALORORCADO) AS VALORORCADO,
			 SUM(TB1.VALORORCADO) + SUM(TB1.VALORORCADOATUALIZADO) AS VALORATUALIZADO,
       SUM(TB1.VALORARRECADADO) AS VALORARRECADADO        
FROM
(SELECT RECEITA_FONTETCE.RECEITA,
			 FONTERECURSO.FONTERECURSO,
		   FONTERECURSO.DESCRICAO,
       RECEITA_FONTETCE.PERCENTUAL,
       COALESCE(((COALESCE(RECEITA.VALORORCADO,0)/100) * COALESCE(RECEITA_FONTETCE.PERCENTUAL,0)),0) AS VALORORCADO,
			 ((SELECT SUM(COALESCE(RECEITAMENSAL.VALORCORRECAOORCADO,0) + COALESCE(RECEITAMENSAL.VALORCORRECAO,0))                                                                                           
					 FROM   RECEITAMENSAL RECEITAMENSAL                                                                                                                                                            
					 WHERE  RECEITAMENSAL.ENTIDADE              = RECEITA.ENTIDADE                                                                                                                                 
					 AND    RECEITAMENSAL.EXERCICIO					    = RECEITA.EXERCICIO                                                                                                                                
					 AND    RECEITAMENSAL.RECEITA								= RECEITA.RECEITA                                                                                                                                  
					 AND    RECEITAMENSAL.FONTERECURSO					= RECEITA.FONTERECURSO                                                                                                                             
					 AND    RECEITAMENSAL.IDTIPOOPERACAORECEITA = RECEITA.IDTIPOOPERACAORECEITA) /100) * COALESCE(RECEITA_FONTETCE.PERCENTUAL,0) AS VALORORCADOATUALIZADO,
           COALESCE((SELECT SUM(CASE WHEN RR.GRUPOEVENTO in (11,14) then RRI.VALOR else RRI.VALOR*-1 END) 
           FROM   REALIZACAORECEITA RR                                                          
           JOIN   REALIZACAORECEITAITEM RRI                                                     
           ON     RRI.ENTIDADE     = RR.ENTIDADE                                                
           AND    RRI.EXERCICIO    = RR.EXERCICIO                                               
           AND    RRI.LANCAMENTO   = RR.LANCAMENTO                                              
           WHERE  RR.ENTIDADE        = RECEITA.ENTIDADE                               
           AND 	  RR.EXERCICIO       = RECEITA.EXERCICIO                                        
           AND    RR.RECEITA         = RECEITA.RECEITA                                        
           AND    RRI.FONTERECURSO   = FONTERECURSO.FONTERECURSO
           AND    RRI.IDTIPOOPERACAORECEITA = RECEITA.IDTIPOOPERACAORECEITA),0) VALORARRECADADO
FROM   RECEITA RECEITA

JOIN RECEITA_FONTETCE RECEITA_FONTETCE                             
	ON  RECEITA_FONTETCE.ENTIDADE    	        = RECEITA.ENTIDADE     
 AND RECEITA_FONTETCE.EXERCICIO             = RECEITA.EXERCICIO     
 AND RECEITA_FONTETCE.RECEITA               = RECEITA.RECEITA       
 AND RECEITA_FONTETCE.FONTERECURSO          = RECEITA.FONTERECURSO  
 AND RECEITA_FONTETCE.IDTIPOOPERACAORECEITA = RECEITA.IDTIPOOPERACAORECEITA

JOIN FONTERECURSO FONTERECURSO                                       
ON  FONTERECURSO.FONTERECURSO = RECEITA_FONTETCE.VINCULOFONTERECURSO 

WHERE  RECEITA.ENTIDADE  		   = :entidade
AND    RECEITA.EXERCICIO           = :exercicio
AND    COALESCE(RECEITA.MOVSN,'N') = 'S'
ORDER BY RECEITA,FONTERECURSO) TB1
GROUP BY TB1.FONTERECURSO,TB1.DESCRICAO ) TB2
WHERE (TB2.VALORORCADO > 0 OR TB2.VALORATUALIZADO > 0 OR TB2.VALORARRECADADO > 0)

==> portal-transparencia-3.22.1.zip: BOOT-INF/classes/db/sql/contab/receitasPorFonteRecurso.sql <==
SELECT TB2.*
FROM
(SELECT CAST(TB1.FONTERECURSO AS NUMERIC(15))  AS RECEITA,
       TB1.DESCRICAO,
			 SUM(TB1.VALORORCADO) AS VALORORCADO,
			 SUM(TB1.VALORORCADO) + SUM(TB1.VALORORCADOATUALIZADO) AS VALORATUALIZADO,
       SUM(TB1.VALORARRECADADO) AS VALORARRECADADO        
FROM
(SELECT RECEITA_FONTETCE.RECEITA,
			 FONTERECURSO.FONTERECURSO,
		   FONTERECURSO.DESCRICAO,
       RECEITA_FONTETCE.PERCENTUAL,
       COALESCE(((COALESCE(RECEITA.VALORORCADO,0)/100) * COALESCE(RECEITA_FONTETCE.PERCENTUAL,0)),0) AS VALORORCADO,
			 ((SELECT SUM(COALESCE(RECEITAMENSAL.VALORCORRECAOORCADO,0) + COALESCE(RECEITAMENSAL.VALORCORRECAO,0))                                                                                           
					 FROM ${db.contabilidade.schema}.RECEITAMENSAL RECEITAMENSAL
					 WHERE  RECEITAMENSAL.ENTIDADE              = RECEITA.ENTIDADE                                                                                                                                 
					 AND    RECEITAMENSAL.EXERCICIO					    = RECEITA.EXERCICIO                                                                                                                                
					 AND    RECEITAMENSAL.RECEITA								= RECEITA.RECEITA                                                                                                                                  
					 AND    RECEITAMENSAL.FONTERECURSO					= RECEITA.FONTERECURSO                                                                                                                             
					 AND    RECEITAMENSAL.IDTIPOOPERACAORECEITA = RECEITA.IDTIPOOPERACAORECEITA) /100) * COALESCE(RECEITA_FONTETCE.PERCENTUAL,0) AS VALORORCADOATUALIZADO,
           COALESCE((SELECT SUM(CASE WHEN RR.GRUPOEVENTO in (11,14) then RRI.VALOR else RRI.VALOR*-1 END) 
           FROM ${db.contabilidade.schema}.REALIZACAORECEITA RR
           JOIN ${db.contabilidade.schema}.REALIZACAORECEITAITEM RRI
           ON     RRI.ENTIDADE     = RR.ENTIDADE                                                
           AND    RRI.EXERCICIO    = RR.EXERCICIO                                               
           AND    RRI.LANCAMENTO   = RR.LANCAMENTO                                              
           WHERE  RR.ENTIDADE        = RECEITA.ENTIDADE                               
           AND 	  RR.EXERCICIO       = RECEITA.EXERCICIO                                        
           AND    RR.RECEITA         = RECEITA.RECEITA                                        
           AND    RRI.FONTERECURSO   = FONTERECURSO.FONTERECURSO
           AND    RRI.IDTIPOOPERACAORECEITA = RECEITA.IDTIPOOPERACAORECEITA),0) VALORARRECADADO
FROM ${db.contabilidade.schema}.RECEITA RECEITA

JOIN ${db.contabilidade.schema}.RECEITA_FONTETCE RECEITA_FONTETCE
	ON  RECEITA_FONTETCE.ENTIDADE    	        = RECEITA.ENTIDADE     
 AND RECEITA_FONTETCE.EXERCICIO             = RECEITA.EXERCICIO     
 AND RECEITA_FONTETCE.RECEITA               = RECEITA.RECEITA       
 AND RECEITA_FONTETCE.FONTERECURSO          = RECEITA.FONTERECURSO  
 AND RECEITA_FONTETCE.IDTIPOOPERACAORECEITA = RECEITA.IDTIPOOPERACAORECEITA

JOIN ${db.contabilidade.schema}.FONTERECURSO FONTERECURSO
ON  FONTERECURSO.FONTERECURSO = RECEITA_FONTETCE.VINCULOFONTERECURSO 

WHERE  RECEITA.ENTIDADE  		   = :entidade
AND    RECEITA.EXERCICIO           = :exercicio
AND    COALESCE(RECEITA.MOVSN,'N') = 'S'
ORDER BY RECEITA,FONTERECURSO) TB1
GROUP BY TB1.FONTERECURSO,TB1.DESCRICAO ) TB2
WHERE (TB2.VALORORCADO > 0 OR TB2.VALORATUALIZADO > 0 OR TB2.VALORARRECADADO > 0)
